// window.spiffy = "http://192.168.240.180:2357/spiffy/dhtmlx-data-store";
window.spiffy = "data-store.xml";
window.dhtmlx = {
    paging: {
        datastore: false,
        grid: false
    },
    smart_rendering: {
        datastore: true,
        grid: false
    }
};

function initDataStore() {
    // Setting the 'url' and 'dataType' here seems to do nothing. Which is
    // funny, because it does make a request, it just doesn't do anything with
    // the data after that.

    //dataStore;

    if (window.dhtmlx.paging.datastore || window.dhtmlx.smart_rendering.datastore) {
        dataStore = new window.dhtmlXDataStore(
            {
                url: window.spiffy + "?paging=true&v=2",
                dataType: "xml"
            }
        );
    }
    else {
        dataStore = new window.dhtmlXDataStore();
    }

    // Even if you set URL and type above, you still need to put them here.
    if (window.dhtmlx.paging.datastore || window.dhtmlx.smart_rendering.datastore)
        dataStore.load(window.spiffy + "?paging=true", "xml");
    else if (! window.dhtmlx.paging.grid && ! window.dhtmlx.smart_rendering.grid)
        dataStore.load("data-store.xml", "xml");

    // This event fires when data is *fetched* from the server, unfortunately
    // not when data is *stored* on the server.

    dataStore.attachEvent('onXLS', function () {
        console.log("Calling onXLS hook.");

        // It's not possible to cancel the load from here.
        return false;
    });

    window.dhtmlx.dataStore = dataStore;
}

function initDataProcessor() {
    var dataProcessor = new window.dataProcessor(window.spiffy);
    dataProcessor.init(window.dhtmlx.dataStore);

    window.dhtmlx.dataProcessor = dataProcessor;
}

function initGrid() {
    var grid = new window.dhtmlXGridObject("grid");
    grid.setImagePath("__WCIMGURLdhtmlx/");

    // if (! window.dhtmlx.paging && ! window.dhtmlx.smart_rendering)
        grid.enableAutoHeight(true, 256);

    if (window.dhtmlx.paging.grid)
        grid.loadXML(window.spiffy + "?paging=true");

    grid.enableMultiselect(true);
    grid.setHeader("Name,Homeland");
    grid.setColumnIds("name,homeland");
    grid.setColSorting('str,str');
    grid.setSkin("dhx_skyblue");

    if (window.dhtmlx.paging.grid || window.dhtmlx.paging.datastore) {
        console.log("Paging: enabled");
        grid.enablePaging(true, 10, null, "grid-paging", true, "grid-paging-state");
        grid.setPagingSkin("bricks");
    }

    grid.init();

    // Enable smart rendering in the grid if we're either: (1) using it directly
    // in the grid, or (2) using it via the datastore. By the way, this is down
    // here because in their example on the forum, they put this after init().
    
    if (window.dhtmlx.smart_rendering.grid || window.dhtmlx.smart_rendering.datastore) {
        console.log("Smart rendering: enabled");
        grid.enableSmartRendering(true, 10);
    }

    // If you get an error here about calling 'appendChild()' on null, make sure
    // you've set the headers above (it's required apparently). Also, if you set
    // this while trying to load your own data in the grid (e.g. with paging)
    // all but the first page will be empty, because it won't try to fetch
    // additional pages beyond the first load.

    if (! window.dhtmlx.paging.grid && ! window.dhtmlx.smart_rendering.grid)
        grid.sync(window.dhtmlx.dataStore);

    grid.attachEvent('onRowAdded', function (rowId) {
        console.log(String.sprintf("Row added: ((rowid . %d) (name . %s) (homeland . %s))",
                                   rowId,
                                   window.dhtmlx.dataStore.item(rowId).name,
                                   window.dhtmlx.dataStore.item(rowId).homeland));
    });

    window.dhtmlx.grid = grid;
}

function addEntry() {
    window.dhtmlx.dataStore.add({
        name: $$('input[name="name"]')[0].value,
        homeland: $$('input[name="homeland"]')[0].value
    });
    return false;
}

function deleteEntry() {
    var grid = window.dhtmlx.grid;
    var dataStore = window.dhtmlx.dataStore;
    var rowIds = grid.getSelectedRowId().split(",");

    window.console.log("Deleting: ((rowid . " + rowIds + "))");
    for (var i = 0; i < rowIds.length; i += 1) {
        // This won't delete the item from the DataStore, nor does it kick off a
        // DataProcessor to the server to delete it there.
        // >> grid.deleteRow(rowIds[i]);

        dataStore.remove(rowIds[i]);
    }

    return false;
}

function initAll() {
    initDataStore();
    initGrid();
    initDataProcessor();
}

// window.addEvent("domready", initAll);
